@@ -6,4 +6,4 @@
 # All rights reserved.
 # -------------------------------
 
-from .juniper_source import main
\ No newline at end of file
+from .juniper_source import exec
\ No newline at end of file
